@@ -211,6 +211,47 @@ class TestCustomer(unittest.TestCase):
         self.assertEqual(1, len(customer.paypal_accounts))
         self.assertIsInstance(customer.paypal_accounts[0], PayPalAccount)
 
+    def test_create_with_paypal_order_payment_nonce(self):
+        http = ClientApiHttp.create()
+        status_code, payment_method_nonce = http.get_paypal_nonce({
+            "intent": "order",
+            "payment-token": "fake-paypal-payment-token",
+            "payer-id": "fake-paypal-payer-id"
+        })
+
+        result = Customer.create({"payment_method_nonce": payment_method_nonce})
+        self.assertTrue(result.is_success)
+
+        customer = result.customer
+        self.assertEqual(1, len(customer.paypal_accounts))
+        self.assertIsInstance(customer.paypal_accounts[0], PayPalAccount)
+
+    def test_create_with_paypal_order_payment_nonce_and_paypal_options(self):
+        http = ClientApiHttp.create()
+        status_code, payment_method_nonce = http.get_paypal_nonce({
+            "intent": "order",
+            "payment-token": "fake-paypal-payment-token",
+            "payer-id": "fake-paypal-payer-id"
+        })
+
+        result = Customer.create({
+            "payment_method_nonce": payment_method_nonce,
+            "options": {
+                "paypal": {
+                    "payee_email": "payee@example.com",
+                    "order_id": "merchant-order-id",
+                    "custom_field": "custom merchant field",
+                    "description": "merchant description",
+                    "amount": "1.23",
+                },
+            },
+        })
+        self.assertTrue(result.is_success)
+
+        customer = result.customer
+        self.assertEqual(1, len(customer.paypal_accounts))
+        self.assertIsInstance(customer.paypal_accounts[0], PayPalAccount)
+
     def test_create_with_paypal_one_time_nonce_fails(self):
         result = Customer.create({"payment_method_nonce": Nonces.PayPalOneTimePayment})
         self.assertFalse(result.is_success)
@@ -907,10 +948,9 @@ class TestCustomer(unittest.TestCase):
             "apple_pay_cards": [{"token": "apple_pay_card"}],
             "android_pay_cards": [{"token": "android_pay_card"}],
             "europe_bank_accounts": [{"token": "europe_bank_account"}],
-            "coinbase_accounts": [{"token": "coinbase_account"}],
             "us_bank_accounts": [{"token": "us_bank_account"}]
             })
 
         payment_method_tokens = [ pm.token for pm in customer.payment_methods ]
 
-        self.assertEqual(sorted(payment_method_tokens), ["android_pay_card", "apple_pay_card", "coinbase_account", "credit_card", "europe_bank_account", "paypal_account", "us_bank_account"])
+        self.assertEqual(sorted(payment_method_tokens), ["android_pay_card", "apple_pay_card", "credit_card", "europe_bank_account", "paypal_account", "us_bank_account"])
