@@ -23,6 +23,41 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertEqual(created_account.token, found_account.token)
         self.assertEqual(created_account.customer_id, found_account.customer_id)
 
+    def test_create_with_paypal_order_payment_nonce_and_paypal_options(self):
+        customer_id = Customer.create().customer.id
+
+        http = ClientApiHttp.create()
+        status_code, payment_method_nonce = http.get_paypal_nonce({
+            "intent": "order",
+            "payment-token": "fake-paypal-payment-token",
+            "payer-id": "fake-paypal-payer-id"
+        })
+
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": payment_method_nonce,
+            "options": {
+                "paypal": {
+                    "payee_email": "payee@example.com",
+                    "order_id": "merchant-order-id",
+                    "custom_field": "custom merchant field",
+                    "description": "merchant description",
+                    "amount": "1.23",
+                },
+            },
+        })
+
+        self.assertTrue(result.is_success)
+        created_account = result.payment_method
+        self.assertEqual(PayPalAccount, created_account.__class__)
+        self.assertEqual("bt_buyer_us@paypal.com", created_account.email)
+        self.assertNotEqual(created_account.image_url, None)
+
+        found_account = PaymentMethod.find(result.payment_method.token)
+        self.assertNotEqual(None, found_account)
+        self.assertEqual(created_account.token, found_account.token)
+        self.assertEqual(created_account.customer_id, found_account.customer_id)
+
     def test_create_returns_validation_failures(self):
         http = ClientApiHttp.create()
         status_code, nonce = http.get_paypal_nonce({
@@ -156,6 +191,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertTrue(result.is_success)
         apple_pay_card = result.payment_method
         self.assertIsInstance(apple_pay_card, ApplePayCard)
+        self.assertNotEqual(apple_pay_card.bin, None)
         self.assertNotEqual(apple_pay_card.token, None)
         self.assertEqual(apple_pay_card.customer_id, customer_id)
         self.assertEqual(ApplePayCard.CardType.MasterCard, apple_pay_card.card_type)
@@ -276,9 +312,11 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertEqual(us_bank_account.routing_number, "021000021")
         self.assertEqual(us_bank_account.last_4, "1234")
         self.assertEqual(us_bank_account.account_type, "checking")
-        self.assertEqual(us_bank_account.account_description, "PayPal Checking - 1234")
         self.assertEqual(us_bank_account.account_holder_name, "Dan Schulman")
         self.assertTrue(re.match(r".*CHASE.*", us_bank_account.bank_name))
+        self.assertEqual(us_bank_account.default, True)
+        self.assertEqual(us_bank_account.ach_mandate.text, "cl mandate text")
+        self.assertIsInstance(us_bank_account.ach_mandate.accepted_at, datetime)
 
     def test_create_fails_with_invalid_us_bank_account_nonce(self):
         customer_id = Customer.create().customer.id
@@ -663,7 +701,7 @@ class TestPaymentMethod(unittest.TestCase):
         })
         self.assertTrue(result.is_success)
 
-        delete_result = PaymentMethod.delete(result.payment_method.token)
+        delete_result = PaymentMethod.delete(result.payment_method.token, {"revoke_all_grants": False})
         self.assertTrue(delete_result.is_success)
         self.assertRaises(NotFoundError, PaymentMethod.find, result.payment_method.token)
 
@@ -689,31 +727,6 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertTrue(updated_credit_card.last_4 == CreditCardNumbers.MasterCard[-4:])
         self.assertTrue(updated_credit_card.expiration_date == "06/2013")
 
-    def test_update_coinbase_account_updates_the_coinbase_account(self):
-        customer_id = Customer.create().customer.id
-
-        result = PaymentMethod.create({
-            "customer_id": customer_id,
-            "payment_method_nonce": Nonces.ApplePayMasterCard
-        })
-
-        self.assertTrue(result.payment_method.default)
-
-
-        coinbase_result = PaymentMethod.create({
-            "customer_id": customer_id,
-            "payment_method_nonce": Nonces.Coinbase
-        })
-        update_result = PaymentMethod.update(coinbase_result.payment_method.token, {
-            "options": {
-                "make_default": True
-            }
-        })
-        self.assertTrue(update_result.is_success)
-        updated_coinbase_account = update_result.payment_method
-        self.assertTrue(updated_coinbase_account.token == coinbase_result.payment_method.token)
-        self.assertTrue(updated_coinbase_account.default)
-
     def test_update_creates_a_new_billing_address_by_default(self):
         customer_id = Customer.create().customer.id
         credit_card_result = CreditCard.create({
@@ -828,6 +841,26 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertTrue(update_result.credit_card_verification.status == CreditCardVerification.Status.ProcessorDeclined)
         self.assertTrue(update_result.credit_card_verification.gateway_rejection_reason is None)
 
+    def test_update_can_pass_custom_verification_amount(self):
+        customer_id = Customer.create().customer.id
+        credit_card_result = CreditCard.create({
+            "cardholder_name": "Card Holder",
+            "customer_id": customer_id,
+            "cvv": "123",
+            "number": CreditCardNumbers.Visa,
+            "expiration_date": "05/2020"
+        })
+        update_result = PaymentMethod.update(credit_card_result.credit_card.token, {
+            "payment_method_nonce": Nonces.ProcessorDeclinedMasterCard,
+            "options": {
+                "verify_card": "true",
+                "verification_amount": "2.34"
+            }
+        })
+        self.assertFalse(update_result.is_success)
+        self.assertTrue(update_result.credit_card_verification.status == CreditCardVerification.Status.ProcessorDeclined)
+        self.assertTrue(update_result.credit_card_verification.gateway_rejection_reason is None)
+
     def test_update_can_update_the_billing_address(self):
         customer_id = Customer.create().customer.id
         credit_card_result = CreditCard.create({
