@@ -60,11 +60,11 @@ class TestTransparentRedirect(unittest.TestCase):
         self.assertTrue(result.is_success)
 
         transaction = result.transaction
-        self.assertEquals(Decimal(TransactionAmounts.Authorize), transaction.amount)
-        self.assertEquals(Transaction.Type.Sale, transaction.type)
-        self.assertEquals("411111", transaction.credit_card_details.bin)
-        self.assertEquals("1111", transaction.credit_card_details.last_4)
-        self.assertEquals("05/2010", transaction.credit_card_details.expiration_date)
+        self.assertEqual(Decimal(TransactionAmounts.Authorize), transaction.amount)
+        self.assertEqual(Transaction.Type.Sale, transaction.type)
+        self.assertEqual("411111", transaction.credit_card_details.bin)
+        self.assertEqual("1111", transaction.credit_card_details.last_4)
+        self.assertEqual("05/2010", transaction.credit_card_details.expiration_date)
 
     def test_transaction_credit_from_transparent_redirect_with_successful_result(self):
         tr_data = {
@@ -83,11 +83,11 @@ class TestTransparentRedirect(unittest.TestCase):
         self.assertTrue(result.is_success)
 
         transaction = result.transaction
-        self.assertEquals(Decimal(TransactionAmounts.Authorize), transaction.amount)
-        self.assertEquals(Transaction.Type.Credit, transaction.type)
-        self.assertEquals("411111", transaction.credit_card_details.bin)
-        self.assertEquals("1111", transaction.credit_card_details.last_4)
-        self.assertEquals("05/2010", transaction.credit_card_details.expiration_date)
+        self.assertEqual(Decimal(TransactionAmounts.Authorize), transaction.amount)
+        self.assertEqual(Transaction.Type.Credit, transaction.type)
+        self.assertEqual("411111", transaction.credit_card_details.bin)
+        self.assertEqual("1111", transaction.credit_card_details.last_4)
+        self.assertEqual("05/2010", transaction.credit_card_details.expiration_date)
 
     def test_customer_create_from_transparent_redirect(self):
         tr_data = {
@@ -109,13 +109,13 @@ class TestTransparentRedirect(unittest.TestCase):
         result = TransparentRedirect.confirm(query_string)
         self.assertTrue(result.is_success)
         customer = result.customer
-        self.assertEquals("John", customer.first_name)
-        self.assertEquals("Doe", customer.last_name)
-        self.assertEquals("Doe Co", customer.company)
-        self.assertEquals("john@doe.com", customer.email)
-        self.assertEquals("312.555.2323", customer.phone)
-        self.assertEquals("614.555.5656", customer.fax)
-        self.assertEquals("www.johndoe.com", customer.website)
+        self.assertEqual("John", customer.first_name)
+        self.assertEqual("Doe", customer.last_name)
+        self.assertEqual("Doe Co", customer.company)
+        self.assertEqual("john@doe.com", customer.email)
+        self.assertEqual("312.555.2323", customer.phone)
+        self.assertEqual("614.555.5656", customer.fax)
+        self.assertEqual("www.johndoe.com", customer.website)
 
     def test_customer_update_from_transparent_redirect(self):
         customer = Customer.create({"first_name": "Sarah", "last_name": "Humphrey"}).customer
@@ -136,8 +136,8 @@ class TestTransparentRedirect(unittest.TestCase):
         self.assertTrue(result.is_success)
 
         customer = Customer.find(customer.id)
-        self.assertEquals("Stan", customer.first_name)
-        self.assertEquals("Humphrey", customer.last_name)
+        self.assertEqual("Stan", customer.first_name)
+        self.assertEqual("Humphrey", customer.last_name)
 
     def test_payment_method_create_from_transparent_redirect(self):
         customer = Customer.create({"first_name": "Sarah", "last_name": "Humphrey"}).customer
@@ -157,9 +157,9 @@ class TestTransparentRedirect(unittest.TestCase):
         result = TransparentRedirect.confirm(query_string)
         self.assertTrue(result.is_success)
         credit_card = result.credit_card
-        self.assertEquals("411111", credit_card.bin)
-        self.assertEquals("1111", credit_card.last_4)
-        self.assertEquals("01/2010", credit_card.expiration_date)
+        self.assertEqual("411111", credit_card.bin)
+        self.assertEqual("1111", credit_card.last_4)
+        self.assertEqual("01/2010", credit_card.expiration_date)
 
     def test_payment_method_update_from_transparent_redirect(self):
         customer = Customer.create({"first_name": "Sarah", "last_name": "Humphrey"}).customer
@@ -183,4 +183,4 @@ class TestTransparentRedirect(unittest.TestCase):
         TransparentRedirect.confirm(query_string)
         credit_card = CreditCard.find(credit_card.token)
 
-        self.assertEquals("12/2012", credit_card.expiration_date)
+        self.assertEqual("12/2012", credit_card.expiration_date)
