@@ -250,9 +250,8 @@ class TestHelper(object):
             "routing_number": "021000021",
             "account_number": "567891234",
             "account_holder_name": "Dan Schulman",
-            "account_description": "PayPal Checking - 1234",
             "ach_mandate": {
-                "text": ""
+                "text": "cl mandate text"
             }
         }
         resp = requests.post(client_token["braintree_api"]["url"] + "/tokens", headers=headers, data=json.dumps(payload) )
@@ -267,6 +266,39 @@ class TestHelper(object):
         token += "_xxx"
         return token
 
+    @staticmethod
+    def generate_valid_ideal_payment_id(amount=TransactionAmounts.Authorize):
+        client_token = json.loads(TestHelper.generate_decoded_client_token({
+            "merchant_account_id": "ideal_merchant_account"
+        }))
+        client = ClientApiHttp(Configuration.instantiate(), {
+            "authorization_fingerprint": client_token["authorizationFingerprint"]
+        })
+        _, configuration = client.get_configuration()
+        route_id = json.loads(configuration)["ideal"]["routeId"]
+        headers = {
+            "Content-Type": "application/json",
+            "Braintree-Version": "2015-11-01",
+            "Authorization": "Bearer " + client_token["braintree_api"]["access_token"]
+        }
+        payload = {
+            "issuer": "RABONL2U",
+            "order_id": "ABC123",
+            "amount": amount,
+            "currency": "EUR",
+            "route_id": route_id,
+            "redirect_url": "https://braintree-api.com",
+        }
+        resp = requests.post(client_token["braintree_api"]["url"] + "/ideal-payments", headers=headers, data=json.dumps(payload) )
+        respJson = json.loads(resp.text)
+        return respJson["data"]["id"]
+
+    @staticmethod
+    def generate_three_d_secure_nonce(gateway, params):
+        url = gateway.config.base_merchant_path() + "/three_d_secure/create_nonce/" + TestHelper.three_d_secure_merchant_account_id
+        response = gateway.config.http().post(url, params)
+        return response["payment_method_nonce"]["nonce"]
+
     @staticmethod
     def create_grant(gateway, params):
         config = gateway.config
@@ -349,11 +381,19 @@ class ClientApiHttp(Http):
     def __http_do(self, http_verb, path, params=None):
         http_strategy = self.config.http_strategy()
         request_body = json.dumps(params) if params else None
-        return http_strategy.http_do(http_verb, path, self.__headers(), request_body)
+        return http_strategy.http_do(http_verb, path, self.__headers(), (request_body, None))
 
     def set_authorization_fingerprint(self, authorization_fingerprint):
         self.options['authorization_fingerprint'] = authorization_fingerprint
 
+    def get_configuration(self):
+        encoded_fingerprint = quote_plus(self.options["authorization_fingerprint"])
+        url = "/merchants/%s/client_api/v1/configuration" % self.config.merchant_id
+        url += "?authorizationFingerprint=%s" % encoded_fingerprint
+        url += "&configVersion=3"
+
+        return self.get(url)
+
     def get_cards(self):
         encoded_fingerprint = quote_plus(self.options["authorization_fingerprint"])
         url = "/merchants/%s/client_api/v1/payment_methods.json" % self.config.merchant_id
