@@ -14,7 +14,7 @@ class TestBusinessDetails(unittest.TestCase):
             }
         })
 
-        regex = "<BusinessDetails {dba_name: 'Bar Suenami', legal_name: 'Suenami Restaurant Group', tax_id: '123001234', address_details: <AddressDetails {street_address: '123 First St', locality: 'NV', region: 'Las Vegas'} at \w+>} at \w+>"
+        regex = r"<BusinessDetails {dba_name: 'Bar Suenami', legal_name: 'Suenami Restaurant Group', tax_id: '123001234', address_details: <AddressDetails {street_address: '123 First St', locality: 'NV', region: 'Las Vegas'} at \w+>} at \w+>"
 
         matches = re.match(regex, repr(details))
         self.assertTrue(matches)
